@@ -16,7 +16,7 @@ class Embeddings(metaclass=abc.ABCMeta):
     """
 
     def __init__(self, index: Iterable[dict], module: gensim.models, output:str=None, text_field='text',
-                 skipgram_ws: int = None, tag=False, id_field:Union[str, List[str]]=None) -> None:
+                 skipgram_ws: int = None, tag=False, id_field:Union[str, List[str]]=None, processing:Callable=None) -> None:
         """
         **\_\_init\_\_**: Creates a new Embeddings instance.
 
@@ -53,18 +53,25 @@ class Embeddings(metaclass=abc.ABCMeta):
         self.model = None
         self.output = output
 
+        if index is None:
+            return
+
+        def process(text):
+            if processing is None: return text
+            return processing(text)
+
         if tag:
-            self.data = [gensim.models.doc2vec.TaggedDocument(words=record[text_field].split(),
+            self.data = [gensim.models.doc2vec.TaggedDocument(words=process(record[text_field]).split(),
                                                               tags=[str(record[self.id_field])])
                          if not skipgram_ws else
                          gensim.models.doc2vec.TaggedDocument(
-                             words=self.self.nlp.split_skipgram(record[text_field], ws=skipgram_ws),
+                             words=self.self.nlp.split_skipgram(process(record[text_field]), ws=skipgram_ws),
                              tags=[str(record[self.id_field])])
                          for record in index]
 
         else:
-            self.data = [record[text_field].split() if not skipgram_ws else
-                         self.nlp.split_skipgram(record[text_field], ws=skipgram_ws)
+            self.data = [process(record[text_field]).split() if not skipgram_ws else
+                         self.nlp.split_skipgram(process(record[text_field]), ws=skipgram_ws)
                          for record in index]
 
     def __getattr__(self, name):
@@ -74,10 +81,10 @@ class Embeddings(metaclass=abc.ABCMeta):
         else:
             return value
 
-    def load(self):
+    def load(self, path):
         """Load a previously saved Embeddings model from file."""
 
-        self.model = self.module.load(self.path)
+        self.model = self.module.load(path)
         return self.model
 
     def save(self):
