@@ -9,6 +9,7 @@ class Fasttext(WordEmbeddings):
 
     Each word is represented as a bag of character n-grams in addition to the word itself. This helps preserve the meaning of shorter words that may show up as ngrams of other words. Inherently, this also allows you to capture meaning for suffixes/prefixes.
     """
-    def __init__(self, index: Iterable[dict], output:str=None, text_field='text', skipgram_ws: int = None):
+    def __init__(self, index: Iterable[dict]=None, output:str=None, text_field='text', skipgram_ws: int = None):
+
         super().__init__(output=output, index=index, text_field=text_field, tag=False, skipgram_ws=skipgram_ws,
                          module=gensim.models.fasttext.FastText)
\ No newline at end of file
