@@ -12,6 +12,6 @@ class Word2vec(WordEmbeddings):
 
     Skip – gram follows the same topology as of CBOW. It just flips CBOW’s architecture on its head. The aim of skip-gram is to predict the context given a word.
     """
-    def __init__(self, index: Iterable[dict], output:str=None, text_field='text', skipgram_ws: int = None):
+    def __init__(self, index: Iterable[dict]=None, output:str=None, text_field='text', skipgram_ws: int = None):
         super().__init__(output=output, index=index, text_field=text_field, tag=False,
                          skipgram_ws=skipgram_ws, module=gensim.models.Word2Vec)
