@@ -1,4 +1,5 @@
 import unidecode
+import sys
 import re
 import spacy
 import string
@@ -44,6 +45,13 @@ class NLP:
         # stemmer
         self.stemmer = SnowballStemmer(language)
 
+        # punctuation list
+        # ascii punctuation characters
+        punctuation = string.punctuation
+        # unicode punctuation characters
+        punctuation += "".join([chr(i) for i in range(sys.maxunicode) if unicodedata.category(chr(i)).startswith('P')])
+        self.punctuation = punctuation
+
         # lexicon
         if nlp_language.sentiment_lexicon_class is not None:
             module = __import__('compling.lexicons')
@@ -171,8 +179,7 @@ class NLP:
         """
         return token.isdigit()
 
-    @staticmethod
-    def is_punct(token: str) -> bool:
+    def is_punct(self, token: str) -> bool:
         """
         Returns True if token is a punctuation character, False otherwise.
 
@@ -182,7 +189,7 @@ class NLP:
         Returns:
             bool: True, if the token is a punctuation character, False otherwise.
         """
-        return token in string.punctuation
+        return token in self.punctuation
 
     @staticmethod
     def is_space(token: str) -> bool:
@@ -197,8 +204,7 @@ class NLP:
         """
         return token in string.whitespace
 
-    @staticmethod
-    def strip_punctuation(text: str, keep: Iterable[str] = None, sc: Iterable[str] = None) -> str:
+    def strip_punctuation(self, text: str, keep: Iterable[str] = None, sc: Iterable[str] = None) -> str:
         """
         Strips punctuation characters from a input text.
 
@@ -211,17 +217,22 @@ class NLP:
             str: The text without punctuation characters.
         """
 
-        punctuation = string.punctuation
         if keep is not None and len(keep) > 0:
-            punctuation = "".join([i for i in punctuation if i not in keep])
+            punctuation = "".join([i for i in self.punctuation if i not in keep])
+        else:
+            punctuation = self.punctuation
+
         if sc is not None and len(sc) > 0:
             punctuation += "".join(sc)
 
         if keep is not None:
-            for k in keep:
-                text = text.replace(k, ' ' + k + ' ')
+            text = text.translate(str.maketrans({k: ' {} '.format(k) for k in keep}))
 
-        return text.translate(str.maketrans(dict.fromkeys(punctuation, ' '))).strip()
+        return self.strip_double_spaces(text.translate(str.maketrans(dict.fromkeys(punctuation, ' '))).strip())
+
+    @staticmethod
+    def strip_double_spaces(text):
+        return " ".join(text.split())
 
     @staticmethod
     def strip_accents(text: str) -> str:
